@@ -1,7 +1,7 @@
 #include <inttypes.h>
 
 #include <sys/ioctl.h>
-#include "linux-input.h"
+#include <linux/input.h>
 
 #define ev_name(code)  ((code) < EV_MAX  && EV_NAME[code]  ? EV_NAME[code]  : "???")
 #define ev_type_name(type, code) ((code) < EV_TYPE_MAX[type] && EV_TYPE_NAME[type][code] ? EV_TYPE_NAME[type][code] : "???")
@@ -25,5 +25,5 @@ static __inline__ int test_bit(int nr, BITFIELD * addr)
 /* ------------------------------------------------------------------ */
 
 int device_open(int nr, int verbose);
-void device_info(int fd);
+int device_info(int nr, int fd, int verbose);
 void print_event(struct input_event *event);
